.. default-role:: literal

Functions
#########

Functions are used in RQL and in various places of manifest. Here is an example
how functios are used in RQL::

  /model?eq(foo,bar)

Here we have function `eq` which is called with two arguments `foo` and `bar`.
